Blob class

Sembast blob definition

Implemented types

Constructors

Blob(Uint8List bytes)
Blob creation.
Blob.fromList(List<int> list)
Blob creation from int list.

Properties

bytes → Uint8List
Blob bytes. null not supported.
final
hashCode → int
The hash code for this object.
no setteroverride
length → int
Blob length.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(Blob other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64() → String
Base64 encoding.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override
operator [](int index) → int
The byte at a given index.

Static Methods

fromBase64(String base64) → Blob
Blob creation from base64.