Boundary class abstract

Sort order boundary, lower or upper to use in a Finder

Constructors

Boundary({RecordSnapshot<Key?, Value?>? record, bool? include, List<Object?>? values})
Create a boundary from a set of values or a given record
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
include → bool
if true, the boundary will be included in the search result.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited