DatabaseFactory class abstract

The database factory that allow opening database

Implementers
Available extensions

Constructors

DatabaseFactory()

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasStorage → bool
True if it has an associated storage (fs, idb).
no setter
pathContext → Context
Path context
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

databaseExists(String path) → Future<bool>
Check if a database exists
deleteDatabase(String path) → Future<void>
Delete a database if existing
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openDatabase(String path, {int? version, OnVersionChangedFunction? onVersionChanged, DatabaseMode? mode, SembastCodec? codec}) → Future<Database>
Open a new or existing database.
sandbox({required String path}) → DatabaseFactory

Available on DatabaseFactory, provided by the SembastDatabaseFactorySandboxExtension extension

Database factory sandboxing.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited