RecordChange<K, V> class abstract

Record change info streamed during StoreRef.onChange.

Handle both add, update and delete

Available extensions

Constructors

RecordChange()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAdd → bool

Available on RecordChange<K, V>, provided by the SembastRecordChangeExtension extension

True if the record was added.
no setter
isDelete → bool

Available on RecordChange<K, V>, provided by the SembastRecordChangeExtension extension

true if the record was deleted.
no setter
isUpdate → bool

Available on RecordChange<K, V>, provided by the SembastRecordChangeExtension extension

True if the record was updated.
no setter
newSnapshot → RecordSnapshot<K, V>?
The new record value, null for record removed
no setter
newValue → V?

Available on RecordChange<K, V>, provided by the SembastRecordChangeExtension extension

The new record value, null for record removed
no setter
oldSnapshot → RecordSnapshot<K, V>?
The previous record snapshot, null for record added.
no setter
oldValue → V?

Available on RecordChange<K, V>, provided by the SembastRecordChangeExtension extension

The previous record value, null for record added.
no setter
ref → RecordRef<K, V>

Available on RecordChange<K, V>, provided by the SembastRecordChangeExtension extension

The record ref.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cast<RK extends Key?, RV extends Value?>() → RecordChange<RK, RV>
Cast if needed
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited