JsonEncodableDecoder class

Decoder.

Inheritance

Constructors

JsonEncodableDecoder(JsonEncodableCodec _codec)
Decoder.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<Object> stream) → Stream<Object>
Transforms the provided stream.
inherited
cast<RS, RT>() → Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(Object input) → Object
Converts input and returns the result of the conversion.
override
fuse<TT>(Converter<Object, TT> other) → Converter<Object, TT>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startChunkedConversion(Sink<Object> sink) → Sink<Object>
Starts a chunked conversion.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited